@@ -2,7 +2,7 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-use std::cmp::Ordering;
+use core::cmp::Ordering;
 
 pub trait BoxedString {
     fn string(&self) -> &String;
